pygeodesy.ltpTuples.Footprint5Tuple

Package pygeodesy :: Module ltpTuples :: Class Footprint5Tuple |
[frames] | no frames]

# Class Footprint5Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Footprint5Tuple

5-Tuple `(center, upperleft, upperight, loweright, lowerleft)` with the `center` and 4 corners of the local projection of a `Frustum`, each an Xyz4Tuple, XyzLocal, `LatLon`, etc.

Note: Misspelling of `upperight` and `loweright` is intentional.

Instance Methods
toLatLon5(self, ltp=None, LatLon=None, **name_LatLon_kwds) Convert this footprint's `center` and 4 corners to geodetic `LatLon(lat, lon, height)`s, `LatLon3Tuple`s or `LatLon4Tuple`s. |
xyzLocal5(self, ltp=None) Return this footprint's `center` and 4 corners as 5 XyzLocals. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toLatLon5 (self, ltp=None, LatLon=None, **name_LatLon_kwds) |
Convert this footprint's `center` and 4 corners to geodetic `LatLon(lat, lon, height)`s, `LatLon3Tuple`s or `LatLon4Tuple`s. Arguments: `ltp` - The local tangent plane (Ltp), overriding this footprint's `center` or `frustrum` `ltp`. `LatLon` - Optional geodetic class (`LatLon`) or `None`. `name_LatLon_kwds` - Optional `name=NN` (`str`) and optionally, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: A Footprint5Tuple of 5 `LatLon(lat, lon, **name_LatLon_kwds)` instances or if `LatLon is None`, 5 LatLon3Tuple`(lat, lon, height)`s respectively 5 LatLon4Tuple`(lat, lon, height, datum)`s depending on whether keyword argument `datum` is un-/specified. Raises: `TypeError` - Invalid `ltp`, `LatLon` or `name_LatLon_kwds` item. See Also: Methods XyzLocal.toLatLon and Footprint5Tuple.xyzLocal5.

### xyzLocal5 (self, ltp=None) |
Return this footprint's `center` and 4 corners as 5 XyzLocals. Arguments: `ltp` - The local tangent plane (Ltp), overriding the {center} and corner `ltp`s. Returns: A Footprint5Tuple of 5 XyzLocal instances. Raises: `TypeError` - Invalid `ltp`.